@@ -347,6 +347,9 @@ readonly class ResourceFactory implements SingletonInterface
         }
         if (MathUtility::canBeInterpretedAsInteger($storageId)) {
             $storage = $this->storageRepository->findByUid($storageId);
+            if ($storage === null) {
+                throw new ResourceDoesNotExistException('Storage ' . $storageId . ' does not exist', 1762852423);
+            }
             if ($storage->hasFile($objectIdentifier)) {
                 return $storage->getFile($objectIdentifier);
             }
@@ -426,9 +429,8 @@ readonly class ResourceFactory implements SingletonInterface
      *
      * @param int $uid The uid of the file usage (sys_file_reference) to be fetched
      * @param bool $raw Whether to get raw results without performing overlays
-     * @return array|null
      */
-    protected function getFileReferenceData(int $uid, bool $raw = false): ?array
+    protected function getFileReferenceData(int $uid, bool $raw = false): array|false|null
     {
         $request = $GLOBALS['TYPO3_REQUEST'] ?? null;
         if (!$raw
